@@ -2,6 +2,7 @@
 """
 TODO combine nearly equal oauth/token flow with gitlab
 """
+
 import json
 import os
 import sys
@@ -26,7 +27,7 @@ def get_endpoint(example='//api.aida.appcloud.my_company.com'):
         try:
             if requests.get(url).status_code in (200, 404):
                 return 'write'
-        except:
+        except Exception:
             print('Not reachable')
             return
 
@@ -41,7 +42,7 @@ def cfg(c=[], all=None):
     """
     try:
         return c[0][FLG.endpoint_name]
-    except:
+    except Exception:
         pass
     c.append(ConfigParser())
     fn = fn_cfg()
@@ -121,7 +122,11 @@ class CloudFoundry:
             ul + '/oauth/token',
             # that is an accepted client id, did cost me 2 hours to find:
             auth=basic('cf', ''),
-            data={'grant_type': 'password', 'username': user, 'password': password,},
+            data={
+                'grant_type': 'password',
+                'username': user,
+                'password': password,
+            },
         )
         res['url'] = h
         res['login_url'] = h = '/oauth/token'
