@@ -12,7 +12,6 @@ using tar -> copy over
 using union2 -> mount overlay(2)
 """
 
-
 import json
 import os
 import socket
@@ -212,7 +211,7 @@ def read(fn):
         s = fd.read()
         try:
             return json.loads(s)
-        except:
+        except Exception:
             return s
 
 
