@@ -11,9 +11,11 @@ from functools import partial
 import importlib
 from devapp.app import app, do, run_app, system
 from devapp.tools import (
+    username,
     offset_port,
     to_list as listed,
     FLG,
+    sp_call,
     project,
     deindent,
     exists,
@@ -35,6 +37,7 @@ class S:
     conda_prefix = None  # env vars replaced
     fs_dir = None  # filesystem install dest
     constants = {}
+    constants_z = {}  # priority of overwriting constants
     rsc_dirs = {}
 
 
@@ -65,6 +68,7 @@ RestartSec       = 5
 SendSIGKILL      = yes
 TimeoutStopSec   = 5
 SyslogIdentifier = %(name)s
+%(user)s
 
 [Install]
 WantedBy = default.target
@@ -75,12 +79,25 @@ unit_match = 'DevApp Unit'
 T_unit = T_unit.replace('_MATCH_', unit_match)
 
 
-def add_const(key, val, skip_exists=True):
-    """import order matters, i.e. 4A's flows file will overrule lc-py"""
+def add_const(key, val, z=0):
+    """import order matters, i.e. 4A's flows file will overrule lc-py. For this we have z now"""
+    # if key == 'fn_flows':
+    #     breakpoint()  # FIXME BREAKPOINT
     v = S.constants.get(key)
     if v is not None:
-        app.warn('Overwriting constant %s' % key, have=v, new=val)
+        zhave = S.constants_z[key]
+        if z < zhave:
+            app.info(
+                'NOT overwriting constant %s' % key,
+                keeping=v,
+                wanted=val,
+                z=z,
+                zhave=zhave,
+            )
+            return
+        app.info('Overwriting constant %s' % key, have=v, new=val, z=z, zhave=zhave)
     S.constants[key] = val
+    S.constants_z[key] = z
 
 
 def constant(key, dflt=None):
@@ -150,7 +167,8 @@ def set_fs_dir():
     S.fs_dir = cli
 
 
-conda_prefix = lambda: S.conda_prefix or [set_conda_prefix(), S.conda_prefix][1]
+def conda_prefix():
+    return S.conda_prefix or [set_conda_prefix(), S.conda_prefix][1]
 
 
 class CommonFlags:
@@ -176,13 +194,22 @@ class CommonFlags:
 # --------------------------------------------------------------------- tools/  actions
 
 simple_types = (bool, int, float, str, list)
-to_struct = lambda s: (to_list if s.name == 'resources' else to_dict)(s)
-to_list = lambda rscs: [to_dict(rsc) for rsc in rscs]
-to_dict = lambda rsc: {
-    k: getattr(rsc, k)
-    for k in dir(rsc)
-    if not k.startswith('_') and isinstance(getattr(rsc, k), simple_types)
-}
+
+
+def to_struct(s):
+    return (to_list if s.name == 'resources' else to_dict)(s)
+
+
+def to_list(rscs):
+    return [to_dict(rsc) for rsc in rscs]
+
+
+def to_dict(rsc):
+    return {
+        k: getattr(rsc, k)
+        for k in dir(rsc)
+        if not k.startswith('_') and isinstance(getattr(rsc, k), simple_types)
+    }
 
 
 # # get some nice respresentation of the rsc classes:
@@ -205,7 +232,8 @@ to_dict = lambda rsc: {
 
 
 # api:
-g = lambda rsc, key, default='': getattr(rsc, key, default)
+def g(rsc, key, default=''):
+    return getattr(rsc, key, default)
 
 
 def gf(rsc, key, default=''):
@@ -237,7 +265,8 @@ def gf(rsc, key, default=''):
 #     return rsc[0]
 
 
-is_fs = lambda rsc: str(g(rsc, 'pkg')).startswith('layers:')
+def is_fs(rsc):
+    return str(g(rsc, 'pkg')).startswith('layers:')
 
 
 def dir_rsc_cfg(rsc):
@@ -272,13 +301,18 @@ def rsc_path(rsc, verify_present=False):
         return path if exists(path + '/' + exe) else None
 
 
-interactive = lambda: '-y' if FLG.force else ''
+def interactive():
+    return '-y' if FLG.force else ''
+
+
 # resources without a package (e.g. client)
-is_no_pkg_rsc = lambda rsc: g(rsc, 'pkg') == False
+def is_no_pkg_rsc(rsc):
+    return g(rsc, 'pkg') is False
 
 
 class Run:
     def get_full_cmd(rsc, sel):
+        spec = {}
         cmd_pre = ''
         if is_no_pkg_rsc(rsc):
             f = gf(rsc, sel, sel)
@@ -318,7 +352,7 @@ class Run:
         cmd = cmd_pre + cmd
         # if not cmd.split(' ')[0] == orig_cmd.split(' ')[0]:
         #     app.info('completing command', given=orig_cmd, completed=cmd)
-        return cmd, spec
+        return cmd, spec or {}
 
 
 def get_instances(rsc):
@@ -327,6 +361,9 @@ def get_instances(rsc):
     return i
 
 
+settings_marker = '# Resource settings:'
+
+
 class Install:
     """Install methods"""
 
@@ -340,7 +377,7 @@ class Install:
         """Api entry: install a resource"""
         Install.requirements(g(rsc, 'req'))
         if not rsc.installed or g(FLG, 'force_reinstall', ''):
-            if g(rsc, 'pkg') == False:
+            if g(rsc, 'pkg') is False:
                 install_mode = Install.no_pkg
             elif is_fs(rsc):
                 install_mode = Install.FS.filesystem
@@ -374,28 +411,62 @@ class Install:
 
     def write_unit_file(name, fn, rsc, instance):
         pn = project.root().rsplit('/', 1)[-1]
+        name = exported_name(rsc, name)
+
         inst_name = f'{name}-{instance}' if instance else name
+        user = ''
+        ddest = dh = os.environ['HOME'] + '/.config/systemd/user'
+        exec = fn
+        if FLG.create_system_units:
+            # here we cannot write directly, will os.system(mv) it after write:
+            dh = '/etc/systemd/system'
+            user = f'User             = {username()}'
+            # selinux only accepts bin files in certain places!
+            exec = '/usr/local/bin/' + '__'.join(fn.split('/')[1:])
         m = {
             'name': inst_name,
             'descr': '%s %s ' % (g(rsc, 'n', inst_name), pn),
             'ctime': time.ctime(),
-            'exec_start': fn,
+            'exec_start': exec,
             'env_instance': instance if instance else '',
+            'user': user,
         }
-        d = os.environ['HOME'] + '/.config/systemd/user'
-        if not exists(d):
-            app.info('creating systemd user dir', dir=d)
-            os.makedirs(d)
+        if not exists(dh):
+            app.info('creating systemd user dir', dir=dh)
+            os.makedirs(dh)
 
         n_svc = '%s-%s.service' % (inst_name, pn)
-        sfn = d + '/' + n_svc
+        sfndest = ddest + '/' + n_svc
+        sfnh = dh + '/' + n_svc
         unit = T_unit % m
-        have = read_file(sfn, dflt='')
-        if unit != have:
-            write_file(sfn, unit)
-            app.info('have written unit file', fn=sfn)
+        have = read_file(sfnh, dflt='')
+        if unit.split('WantedBy', 1)[0] != have.split('WantedBy', 1)[0]:
+            os.environ['unit_file_changed'] = '1'
+            write_file(sfndest, unit)
+            app.info('have written unit file', fn=sfndest)
+            if FLG.create_system_units:
+                app.info(f'Will now try move it to {dh}')
+                r = sp_call('mv', sfndest, sfnh, as_root=True, get_all=True)
+
+                def Die(what, d, r):
+                    return app.die(
+                        f'Could not move {what} file',
+                        wanted_dest=d,
+                        json=r,
+                        hint='sudo password problem?',
+                        silent=True,
+                    )
+
+                Die('unit', sfnh, r) if r['exit_status'] != 0 else 0
+                # selinux only accepts bin files in certain places!
+                app.info('Moving to /usr/local/bin', fn=fn, exec=exec, hint='selinux...')
+                r = sp_call('mv', fn, exec, as_root=True, get_all=True)
+                Die('bin wrapper', exec, r) if r['exit_status'] != 0 else 0
+                app.info('symlinking', fn=fn, exec=exec)
+                os.system(f'ln -s "{exec}"  "{fn}"')
+
         else:
-            app.debug('unit file unchanged', fn=sfn)
+            app.info('unit file unchanged', fn=sfnh)
         return n_svc
 
     def write_starter_and_unit_file(rsc):
@@ -404,6 +475,19 @@ class Install:
         env['d_bin'] = project.root() + '/bin'
 
         def write(cmd, fcmd, spec, instance=0, scmds=[]):
+            def env_settings_info_for_start_wrapper(rsc):
+                e = os.environ.get
+                r = ''
+                for ek in g(rsc, 'environ', ()):
+                    n = f'{rsc.name}_{ek}'
+                    v = e(n)
+                    if v:
+                        v = v.replace("'", "\\'")
+                        r += f'  {n}={v}\n'
+                if r:
+                    r = 'With Env:\n' + r
+                return r
+
             # if cmd == 'dot':
             #    breakpoint()  # FIXME BREAKPOINT
             if isinstance(spec, str):
@@ -411,10 +495,11 @@ class Install:
             app.debug('writing bin/' + cmd, cmd=fcmd)
             pre_exec = spec.pop('pre_exec', '')
             spec_env = spec.pop('env', {})
-            fn = project.root() + '/bin/%s' % cmd
+            fn_name = exported_name(rsc, cmd)
+            fn = project.root() + '/bin/%s' % fn_name
             have = read_file(fn, '')
             marker = '-AUTOCREATED- '
-            if have and len(have.split('\n' + marker, 1)[0].splitlines()) > 8:
+            if have and len(have.split(settings_marker)[0].split('\n' + marker, 1)) == 1:
                 return app.warn(
                     'Skipping write of starter file, marker was manually removed',
                     fn=fn,
@@ -426,30 +511,42 @@ class Install:
                 call = call.rsplit('/', 1)[-1] + ' ' + args
             else:
                 call = call + '\\\n' + args
+            i = rsc
+            D = '\n'.join([f'# {l}' for l in rsc.doc.splitlines()]) or ''
             r = [
                 '#!/usr/bin/env bash',
-                '',
-                '# Delete line containing "%s" to avoid overwrites of this file at project init'
+                D,
+                '# Delete line containing "%s" to avoid overwrites of this file by next resource install.'
                 % marker,
                 "_='%s" % time.ctime(),
                 marker,
                 '%s' % call,
+                env_settings_info_for_start_wrapper(rsc),
                 "'",
             ]
             add = r.append
+            if g(rsc, 'systemd', None) is True:
+                rsc.systemd = cmd
             units = g(FLG, 'init_create_unit_files', [])
             if g(FLG, 'init_create_all_units'):
                 units.extend(listed(g(rsc, 'systemd', None)))
-
             has_unit = False
+            sudo = ''
+            typ = '--user '
+            if FLG.create_system_units:
+                sudo = 'sudo '
+                typ = ''
             if any([u for u in units if u == cmd]):
                 has_unit = True
                 n_svc = Install.write_unit_file(cmd, fn, rsc, instance)
-                scmd = f'systemctl --user --no-pager "$1" "{n_svc}"'
+                scmd = f'{sudo}systemctl {typ}--no-pager ${{*:-}} "{n_svc}"'
+                jcmd = f'{sudo}journalctl {typ}-u "{n_svc}"'
                 if instances:
-                    _ = f'\n        systemctl --user --no-pager "$1" "{n_svc}" '
-                    scmds.append(_)
+                    jcmd = jcmd.rsplit('-', 1)[0] + '-\\*.service"'  # wildcard
+                    _ = f'\n        {sudo}systemctl {typ}--no-pager ${{*:-}} "{n_svc}"'
+                    scmds.append(_)  # adding one more per loop
                     scmd = ''.join(scmds)
+
                 s = """
 
                 case "${1:-}" in
@@ -458,9 +555,14 @@ class Install:
                         _CMD_
                         exit $?
                         ;;
+                    j)
+                        shift && set -x
+                        _JCMD_ "$@"
+                        exit $?
+                        ;;
                 esac
                 """
-                s = s.replace('_CMD_', scmd)
+                s = s.replace('_CMD_', scmd).replace('_JCMD_', jcmd)
                 add(deindent(s))
 
             # env['PATH'] = '%s:$PATH' % g(rsc, 'path')
@@ -470,12 +572,12 @@ class Install:
             add('# set e.g. in unit files:')
             add('test -n "$INSTANCE" && inst_postfix="-$INSTANCE" || inst_postfix=""')
             add('')
-            add('# Resource settings:')
+            add(settings_marker)
             # for whoever needs that:
             allk = set()
             for m in to_dict(rsc), spec, spec_env:
                 for k, v in sorted(m.items()):
-                    if k == 'cmd_pre':
+                    if k in {'cmd_pre', 'doc'}:
                         continue
                     allk.add(k)
                     if k == 'port':
@@ -491,7 +593,7 @@ class Install:
             add('')
             # only for services. Tools not: (e.g. cd mydir && git status -> bum, differentdir)
             if has_unit:
-                add('cd "%s"' % project.root())
+                add('builtin cd "$PROJECT_ROOT"')
             # for client but also possibly other python resources:
             env['PYTHONPATH'] = env.get('PYTHONPATH', '')
             add('export PYTHONPATH="%(d_conf)s:%(PYTHONPATH)s"' % env)
@@ -504,7 +606,8 @@ class Install:
             p += ':' + d
             add('export PATH="$path:%s"' % p)
             add('')
-
+            _ = '$PROJECT_ROOT/.creds_$bin_name'
+            add(f'test -e "{_}" && {{ set -a && . "{_}" && set +a; }}')
             add('return 2>/dev/null # when sourced\n')
 
             if pre_exec:
@@ -548,7 +651,7 @@ class Install:
             D = S.conda_prefix
 
             # return False if not dp else all([exists(dp + '/' + p) for p in rsc.provides])
-            if not exists(D + '/bin/'):
+            if not exists(D):
                 app.warn('Conda base not fully installed')
                 do(Install.Conda.base, location=D)
 
@@ -561,18 +664,19 @@ class Install:
             # if os.system('type micromamba') == 0 or 1:
             if S.is_mamba and mamba and MRP:
                 ctx['conda'] = mamba
-                # FIXME: The activate during docker build is a problem in micromamba which runs as subprocess
-                # Better create the env via micromamba create -n foo -f <yaml file> first
+                # The activate during docker build is a problem in micromamba which runs as subprocess
                 cmd = [
                     '%(conda)s create %(yes)s -n "%(name)s"',
                     f'. "{MRP}/etc/profile.d/micromamba.sh"',
                     'micromamba activate "%(name)s"',
                 ]
+                # in mamba containers we don't have the .sh file
+                # os.system in python often sees not bash but a minimal shell only
+                if not exists(f'. "{MRP}/etc/profile.d/micromamba.sh"'):
+                    cmd[1] = f'eval "$("{mamba}" shell hook --shell=dash)"'
 
             elif S.is_mamba and mamba:
                 ctx['conda'] = mamba
-                # FIXME: The activate during docker build is a problem in micromamba which runs as subprocess
-                # Better create the env via micromamba create -n foo -f <yaml file> first
                 cmd = [
                     '%(conda)s create %(yes)s -n "%(name)s"',
                     'eval "$(%(conda)s shell hook --shell=bash)"',
@@ -652,7 +756,7 @@ class Install:
                 os.chdir(here)
                 environ['PATH'] = pth
 
-            # Usually pf installs - except:
+            # Usually pf installs - except Exception:
             # special case for tools, it has not a single cmd but a list of provides.
             # no cmd -> not yet install_conda_env was run. we do it now via this conventin:
             if res == 'install_conda_env':
@@ -712,7 +816,7 @@ def find_resources_files_in_sys_path():
 
     def find_file_in_pth(pth, d, files=files):
         fn = '%s/%s/operations/resources.py' % (pth, d)
-        if exists(fn) and not d in files:
+        if exists(fn) and d not in files:
             files[d] = fn
             S.rsc_dirs[fn] = pth + '/' + d
 
@@ -723,7 +827,17 @@ def find_resources_files_in_sys_path():
     return files
 
 
-def complete_attrs(rsc, fn):
+def doc(rsc, d=''):
+    for r in rsc.mro():
+        d = g(r, '__doc__', '')
+        if d:
+            return d
+    return d
+
+
+def complete_attrs(rsc):
+    fn = rsc._filename
+
     def to_name(rsc, p):
         if callable(p):
             n = p.__name__
@@ -742,18 +856,23 @@ def complete_attrs(rsc, fn):
         if vn != v:
             setattr(rsc, k, vn)
 
-    rsc.doc = rsc.__doc__ or ''
+    rsc.doc = doc(rsc)
     rsc.name = rsc.__name__
+    rsc.bin_name = exported_name(rsc)
     rsc.module = rsc.__module__.replace('.operations.resources', '')
     rsc.__repr__ = lambda r: str(to_dict(r))
     rsc.__str__ = lambda r: to_str(r)
     rsc.module_dir = S.rsc_dirs[fn]
-    rsc.host_conf_dir = '$PROJECT_ROOT/conf/${host:-$HOSTNAME}/' + rsc.name
+    rsc.host_conf_dir = '$PROJECT_ROOT/conf/${host:-$HOSTNAME}/' + exported_name(rsc)
     rsc.disabled = g(rsc, 'disabled', g(rsc, 'd', False))
     rsc.installed = g(rsc, 'installed', False)
     [repl_callable(rsc, k, getattr(rsc, k)) for k in dir(rsc) if not k.startswith('_')]
 
 
+def exported_name(rsc, d=None):
+    return os.environ.get(f'{rsc.name}_name', d if d else rsc.name)
+
+
 def to_str(rsc):
     svc = g(rsc, 'systemd')
     i = 'i' if g(rsc, 'installed') else ' '
@@ -810,19 +929,20 @@ def find_resource_defs(_have_mod={}):
             _have_mod[n_mod] = fn
             mod = importlib.import_module(n_mod)
         except Exception as ex:
-            return app.error('Cannot import', package=n_mod, fn=fn)
+            return app.error('Cannot import', package=n_mod, fn=fn, exc=ex)
         mod.rsc._package = d
         mod.rsc._filename = fn
 
         rsc_clses = rsc_classes(mod.rsc)
-        [complete_attrs(r, fn) for r in rsc_clses]
+        for r in rsc_clses:
+            r._filename = fn
+            r.module = r.__module__.replace('.operations.resources', '')
 
         rscs.extend(rsc_clses)
 
     {find_cls_in_pth(d, fn) for d, fn in rsc_files.items()}
 
     def remove_redefined_rscs(rscs=rscs):
-
         # this removes the identical ones:
         all = set(rscs)
         # assert len(all) == len(rscs)
@@ -839,6 +959,8 @@ def find_resource_defs(_have_mod={}):
             app.info('%s resources redefined' % (i - j))
 
     remove_redefined_rscs()
+
+    [complete_attrs(r) for r in rscs]
     # remove dubs (through class rsc(other_rsc))
     rscs = set(rscs)
     # sort by name:
