@@ -2,7 +2,6 @@ try:
     __import__('pkg_resources').declare_namespace(__name__)
 
 except ImportError:
-
     from pkgutil import extend_path
 
     __path__ = extend_path(__path__, __name__)
@@ -16,7 +15,7 @@ try:
     pass
 except ImportError as ex:
     ex.args += (
-        'Hint: You have to add structlog to your packages.' '=> pip install structlog',
+        'Hint: You have to add structlog to your packages.=> pip install structlog',
     )
     raise
 
