@@ -11,7 +11,6 @@ Usage:
     The app may use flags: --log_level=20
 """
 
-
 import json
 import os
 import sys
@@ -28,7 +27,7 @@ import structlog
 #     log_dev_coljson_style = ('paraiso-dark',)
 try:
     import ujson
-except Exception as ex:
+except Exception:
     pass  # that's ok - app to the app to depend on it
 from pygments.styles import get_all_styles
 from structlog import BoundLoggerBase, PrintLogger, wrap_logger
@@ -42,7 +41,7 @@ from structlogging import processors as ax_log_processors
 from devapp.tools import FLG, define_flags
 
 pygm_styles = list(get_all_styles())
-pygm_styles.extend(['light', 'dark'])
+pygm_styles.extend(['light', 'dark', 'ax'])
 
 
 class flags(stacktrace.flags):
@@ -56,30 +55,51 @@ class flags(stacktrace.flags):
         n = 'Log time format. Shortcuts: "ISO", "dt"'
         d = '%m-%d %H:%M:%S'
 
+    class log_to_stdout:
+        n = 'Default: stderr'
+        d = False
+
     class log_fmt:
+        """🟢 Json logging has far better performance then the colored console dev log.
+        You can pipe e.g. journalctl output into "ops log_view -fn -" to get dev logging from json.
+
+        This value can be set away from auto via export log_fmt as well.
+        """
+
         n = 'Force a log format. 0: off, 1: auto, 2: plain, 3: plain_no_colors, 4: json. '
-        n += 'Note: This value can be set away from auto via export log_fmt as well.'
         d = 'auto'
 
     class log_add_thread_name:
         n = 'Add name of thread'
         d = False
 
-    class log_dev_fmt_coljson:
-        n = 'List of keys to log as json.'
-        d = 'json,payload'
-        t = list
-
     class log_thread_local_names:
         n = 'Prefer thread local logger_name, when set'
         d = False
 
+    class log_dev_match:
+        n = 'Regex to search in loglines - will be highlighted.'
+        d = ''
+
+    class log_dev_dimm_no_match:
+        n = 'Dimm not matching lines (in colored output only)'
+        d = False
+
     class log_dev_coljson_style:
         n = 'Pygments style for colorized json. To use the 16 base colors and leave it '
-        n += 'to the terminal palette how to render choose light or dark'
+        n += 'to the terminal palette how to render: Choose light or dark'
         t = sorted(pygm_styles)
         d = 'dark'
 
+    class log_dev_coljson_no_truecolor:
+        n = 'NOT use true color for styles (e.g. when no terminal support)'
+        d = False
+
+    class log_dev_fmt_coljson:
+        n = 'List of keys to log as json.'
+        d = 'json,payload'
+        t = list
+
 
 define_flags(flags)
 
@@ -182,8 +202,7 @@ class AppLogLevel:
         self.level = level
         try:
             self.was_level = app.log._logger.level
-        except Exception as ex:
-
+        except Exception:
             print('init_app_parse_flags not yet ran')
             raise
 
@@ -196,7 +215,11 @@ class AppLogLevel:
 
 # setting all level methods, like log.warn into the logger:
 for l, nr in log_levels.items():
-    setattr(AXLogger, l, lambda self, ev, _meth_=l, **kw: self.log(ev, kw, _meth_))
+
+    def meth(self, ev, _meth_=l, **kw):
+        return self.log(ev, kw, _meth_)
+
+    setattr(AXLogger, l, meth)
 
 
 def get_logger(name, level=None, **ctx):
@@ -206,7 +229,8 @@ def get_logger(name, level=None, **ctx):
 
     FLG.log_level = int(log_levels.get(FLG.log_level, FLG.log_level))
     level = level or FLG.log_level
-    log = wrap_logger(PrintLogger(file=sys.stderr), wrapper_class=AXLogger)
+    f = sys.stdout if FLG.log_to_stdout else sys.stderr
+    log = wrap_logger(PrintLogger(file=f), wrapper_class=AXLogger)
     log._logger.name = name
     log._logger.level = level
     return log.bind(**ctx)
@@ -234,7 +258,7 @@ def censor_passwords(_, __, ev, _censored=censored):
             for part in pkw:
                 try:
                     pw = pw.get(part)
-                except Exception as ex:
+                except Exception:
                     pw = None
                 if not pw:
                     break
@@ -257,7 +281,7 @@ def censor_passwords(_, __, ev, _censored=censored):
 
 try:
     import gevent
-except:
+except Exception:
     gevent = None
 
 
@@ -306,7 +330,7 @@ def log_dropper(*a):
 def to_str(obj):
     try:
         return obj.decode('utf-8')
-    except:
+    except Exception:
         return str(obj)
 
 
@@ -315,10 +339,10 @@ def safe_dumps(obj, to_str=to_str, default=None):
         # fails when objects are in, e.g. connection sockets:
         # can dump tuple keys
         return ujson.dumps(obj, ensure_ascii=False, reject_bytes=False)
-    except:
+    except Exception:
         try:
             return json.dumps(obj, default=default)
-        except Exception as ex:
+        except Exception:
             return json.dumps(
                 {
                     'event': 'cannot log-serialize: %s' % str(obj),
@@ -346,7 +370,7 @@ def setup_logging(
     """
     # try:
     #     log_fmt = FLG.log_fmt
-    # except:
+    # except Exception:
     #     breakpoint()  # FIXME BREAKPOINT
     #     FLG = F
 
@@ -357,12 +381,14 @@ def setup_logging(
     log_add_thread_name     = FLG.log_add_thread_name
     log_dev_coljson_style   = FLG.log_dev_coljson_style
     log_dev_fmt_coljson_flg = FLG.log_dev_fmt_coljson
+    log_dev_match           = FLG.log_dev_match
+    log_dev_dimm_no_match   = FLG.log_dev_dimm_no_match
     # fmt:on
     stacktrace.set_log_stack_cfg(FLG)
 
     if censor:
         censor = [censor] if isinstance(censor, str) else censor
-        [censored.append(c) for c in censor if not c in censored]
+        [censored.append(c) for c in censor if c not in censored]
 
     fmt = fmt_to_int(log_fmt)
     tty = sys.stdout.isatty()
@@ -381,6 +407,12 @@ def setup_logging(
 
         # fmt_vals['stack'] = 'f_coljson'  # stack tracebacks always
         s = log_dev_coljson_style
+        if s == 'ax':
+            from theming.term import add_ax_pygm_style
+
+            add_ax_pygm_style()
+        if not FLG.log_dev_coljson_no_truecolor:
+            s = 'true:' + s
         val_formatters['f_coljson'] = {'formatter': 'coljson', 'style': s}
         val_formatters['print_stack'] = {'formatter': 'stack'}
 
@@ -390,7 +422,12 @@ def setup_logging(
         from structlogging import renderers
 
         rend = renderers.ThemeableConsoleRenderer(
-            colors=colors, fmt_vals=fmt_vals, val_formatters=val_formatters
+            colors=colors,
+            fmt_vals=fmt_vals,
+            val_formatters=val_formatters,
+            structlog_style=s,
+            match=log_dev_match,
+            dimm_no_match=log_dev_dimm_no_match,
         )
 
     if get_renderer:
